Aggregation types - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Aggregation types

Aggregation types
Aggregation type | Meaning
avg | The average value in the aggregation period.
avg_ge(val) | The number of days where the average value is greater than or equal to val. Aggregation period must be one day or longer. The argument val is a ValueTuple.
avg_le(val) | The number of days where the average value is less than or equal to val. Aggregation period must be one day or longer. The argument val is a ValueTuple.
count | The number of non-null values in the aggregation period.
diff | The difference between the last and first value in the aggregation period.
exists | Returns True if the observation type exists in the database.
first | The first non-null value in the aggregation period.
firsttime | The time of the first non-null value in the aggregation period.
gustdir | The direction of the max gust in the aggregation period.
has_data | Returns True if the observation type exists in the database and is non-null.
last | The last non-null value in the aggregation period.
lasttime | The time of the last non-null value in the aggregation period.
max | The maximum value in the aggregation period.
maxmin | The maximum daily minimum in the aggregation period. Aggregation period must be one day or longer.
maxmintime | The time of the maximum daily minimum.
maxsum | The maximum daily sum in the aggregation period. Aggregation period must be one day or longer.
maxsumtime | The time of the maximum daily sum.
maxtime | The time of the maximum value.
max_ge(val) | The number of days where the maximum value is greater than or equal to val. Aggregation period must be one day or longer. The argument val is a ValueTuple.
max_le(val) | The number of days where the maximum value is less than or equal to val. Aggregation period must be one day or longer. The argument val is a ValueTuple.
meanmax | The average daily maximum in the aggregation period. Aggregation period must be one day or longer.
meanmin | The average daily minimum in the aggregation period. Aggregation period must be one day or longer.
min | The minimum value in the aggregation period.
minmax | The minimum daily maximum in the aggregation period. Aggregation period must be one day or longer.
minmaxtime | The time of the minimum daily maximum.
minsum | The minimum daily sum in the aggregation period. Aggregation period must be one day or longer.
minsumtime | The time of the minimum daily sum.
mintime | The time of the minimum value.
min_ge(val) | The number of days where the minimum value is greater than or equal to val. Aggregation period must be one day or longer. The argument val is a ValueTuple.
min_le(val) | The number of days where the minimum value is less than or equal to val. Aggregation period must be one day or longer. The argument val is a ValueTuple.
not_null | Returns truthy if any value over the aggregation period is non-null.
rms | The root mean square value in the aggregation period.
sum | The sum of values in the aggregation period.
sum_ge(val) | The number of days where the sum of value is greater than or equal to val. Aggregation period must be one day or longer. The argument val is a ValueTuple.
sum_le(val) | The number of days where the sum of value is less than or equal to val. Aggregation period must be one day or longer. The argument val is a ValueTuple.
tderiv | The time derivative between the last and first value in the aggregation period. This is the difference in value divided by the difference in time.
vecavg | The vector average speed in the aggregation period.
vecdir | The vector averaged direction during the aggregation period.